function [ Out, Result, xyz] = read_shell_FM( LCase )
%read_shell_FM - read the values of Nodal Forces for selected Shell
% Elements in a SAP2000 open instance
%
%   INPUT
%   LCase: string that contain the Load Case Name
%   
%   OUTPUT
%   Out:      0 if the reading process is correct
%   
%   Result:  Average Values of 
% F11,F22,F12,FMax,FMin,FAngle,M11,M22,M12,MMax,MMin,MAngle + element no.
% the average is made over the shell joints
%   xyz: array containing the coordinates of the 
%        nodes eventually selected
%

Out = 1;
%Result = {};

% Inizializzazione modello SAP2000
% INITIALIZATION
% Set the program executable path
ProgramPath = 'C:\Program Files\Computers and Structures\SAP2000 24\SAP2000.exe';
feature('COM_SafeArraySingleDim', 1);
feature('COM_PassSafeArrayByRef', 1);
% Set the API dll path
APIDLLPath = 'C:\Program Files\Computers and Structures\SAP2000 24\SAP2000v1.dll';
% Create OAPI helper object
a = NET.addAssembly(APIDLLPath);
helper = SAP2000v1.Helper;
helper = NET.explicitCast(helper,'SAP2000v1.cHelper');
% Create Sap2000 object
%SapObject = helper.CreateObject(ProgramPath);
% Link to an existing Sap2000 Object
SapObject = helper.GetObject('CSI.SAP2000.API.SapObject');
SapObject = NET.explicitCast(SapObject,'SAP2000v1.cOAPI');
% Start Sap2000 application
%SapObject.ApplicationStart;
% Hide Sap2000 application
%SapObject.Hide;
% Create SapModel object
SapModel = NET.explicitCast(SapObject.SapModel,'SAP2000v1.cSapModel');
% Initialize model
%SapModel.InitializeNewModel;
% Open user defined .sdb model: set FileName as the name of the model
% to be analyzed
%File = NET.explicitCast(SapModel.File,'SAP2000v1.cFile');
%File.OpenFile([pwd, '\', FileName, '.sdb']);
% Set units
%SapModel.SetPresentUnits(SAP2000v1.eUnits.kN_m_C);
% Unlock the model
%SapModel.SetModelIsLocked(false);

AnalysisResults = NET.explicitCast(SapModel.Results,'SAP2000v1.cAnalysisResults');
AnalysisResultsSetup = NET.explicitCast(AnalysisResults.Setup,'SAP2000v1.cAnalysisResultsSetup');
ret = AnalysisResultsSetup.SetCaseSelectedForOutput('DEAD');
SelObj = NET.explicitCast(SapModel.SelectObj,'SAP2000v1.cSelect');
PObj = NET.explicitCast(SapModel.PointObj,'SAP2000v1.cPointObj');
% memo: methods(SelObj)
% 
% read the selected elements

ElemSel=0;
ObjectType=0;
ObjName=cellstr('');
%SelObj.All()
[ret,~,ObjectType,ObjName] = SelObj.GetSelected(ElemSel,ObjectType,ObjName);
ObjName=cell(ObjName);
ObjectType=double(ObjectType);
ShellObj=ObjName(find(ObjectType==5));
PointObj=ObjName(find(ObjectType==1));


for ii = 1:length(ShellObj)
    ItemType = SAP2000v1.eItemTypeElm;
    NumberResults = 0;
    Obj = cellstr('');
    Elm = cellstr('');
    PointElm = cellstr('');
    LoadCase = cellstr('');
    StepType = cellstr('');
    StepNum = 0;
    F11 = 0;
    F22 = 0;
    F12 = 0;
    FMax = 0;
    FMin = 0;
    FAngle = 0;
    FVM = 0;
    M11 = 0;
    M22 = 0;
    M12 = 0;
    MMax = 0;
    MMin = 0;
    MAngle = 0;
    V13 = 0;
    V23 = 0;
    VMax = 0;
    VAngle = 0;
        
    [~, ~, ~, Elm, PointElm, ~,StepType, StepNum,F11,F22,F12,FMax,FMin,FAngle,~,M11,M22,M12,MMax,MMin,MAngle,~,~,~,~] =...
        AnalysisResults.AreaForceShell(ShellObj{ii}, ItemType, NumberResults, Obj, Elm, PointElm, LoadCase, StepType,...
        StepNum,F11,F22,F12,FMax,FMin,FAngle,FVM,M11,M22,M12,MMax,MMin,MAngle,V13,V23,VMax,VAngle);
    disp(ShellObj{ii})
    F11 = double(F11);
    F22 = double(F22);
    F12 = double(F12);
    FMax = double(FMax);
    FMin = double(FMin);
    FAngle = double(FAngle);
    FVM = double(FVM);
    M11 = double(M11);
    M22 = double(M22);
    M12 = double(M12);
    MMax = double(MMax);
    MMin = double(MMin);
    MAngle = double(MAngle);
    V13 = double(V13);
    V23 = double(V23);
    VMax = double(VMax);
    VAngle = double(VAngle);
    Elm=cell(Elm);
    
    PuntiShell{ii,1} = cell(PointElm);
    
    appoRes= mean([F11',F22',F12',FMax',FMin',FAngle',M11',M22',M12',MMax',MMin',MAngle']); % [Result;FM_Read]; %#ok<AGROW>
    disp(appoRes)
    Result(ii,:)=[appoRes, ii];
    
    % not used - old version   
%     NomeSezione = '';
%     [~,NomeSezione]=SapModel.AreaObj.GetProperty(NomiShell{ii,1},NomeSezione);
%     
%     ShellType = 0;
%     MatProp = '';
%     MatAng = 0;
%     ThicknessM = 0;
%     ThicknessB = 0;
%     Color = 0;
%     Notes = '';
%     GUID = '';
%     
%     [~,~,~,~,ThicknessM,~, ~, ~, ~] = SapModel.PropArea.GetShell(NomeSezione,ShellType,...
%         MatProp,MatAng,ThicknessM,ThicknessB,Color,Notes,GUID);
%     
%     NomiShell{ii,2}=ThicknessM;
end

% get the selected nodes coordinates
if not(isempty(PointObj))
    for ii = 1:length(PointObj)
        ItemType = SAP2000v1.eItemTypeElm;
        NumberResults = 0;
        Obj = cellstr('');
        Elm = cellstr('');
        Point = cellstr('');
        LoadCase = cellstr('');
        StepType = cellstr('');
        StepNum = 0;
        x = 0;
        y = 0;
        z = 0;
        [ret,x,y,z]=PObj.GetCoordCartesian(PointObj{ii},0,0,0);
        
        x=double(x);
        y=double(y);
        z=double(z);
        
        xyz(ii,:)=[x y z];
        
    end
else
    xyz=[];
end

Out = 0;

end

